@@ -21,7 +21,6 @@
 /* #define BSD42    1 */
 /* #define BSD43    1 */
 /* #define SUN40    1 */
-/* #define ZONEINFO 1 */
 
 /*
  * Irix
@@ -54,7 +53,16 @@
 /* #define BSD42    1 */
 /* #define BSD43    1 */
 /* #define BSD44    1 */
-/* #define ZONEINFO 1 */
+
+/*
+ * SCO 4.x, 5.x
+ *
+ * I believe the second `define' is only necessary
+ * for SCO 5.x, not SCO 4.x
+ */
+/* #define SYS5         1 */
+/* #define SCO_5_STDIO  1 */
+
 
 /*
  * Define to 1 the type of file locking to use.  You need to
@@ -107,6 +115,15 @@
  */
 #define MIME    1
 
+/*
+ * Compile simple ftp client into mhn.  This will be used by mhn
+ * for ftp access unless you have specified another access method
+ * in your .mh_profile or mhn.defaults.  Use the "mhn-access-ftp"
+ * profile entry to override this.  Check mhn(1) man page for
+ * details.
+ */
+#define FTP     1
+
 /*
  * If you enable POP support, this is the the port name
  * that nmh will use.  Make sure this is defined in your
@@ -187,6 +204,12 @@
 /* Define to `unsigned int' if <sys/types.h> or <signal.h> doesn't define */
 #undef sigset_t
 
+/* Define to `unsigned short' if <sys/types> or <stdlib.h> doesn't define */
+#undef ushort
+
+/* Define to `unsigned long' if <sys/types> or <stdlib.h> doesn't define */
+#undef ulong
+
 /*
  * Define to 1 if your vi has ATT bug, such that it returns
  * non-zero exit codes on `pseudo-errors'.
@@ -202,3 +225,6 @@
 
 /* Define if your system defines `struct winsize' in sys/ptem.h.  */
 #undef WINSIZE_IN_PTEM
+
+/* Define to 1 if struct tm has gmtoff */
+#undef HAVE_TM_GMTOFF
