@@ -44,12 +44,12 @@ int mbx_uucp(void);
 int mbx_open (char *, uid_t, gid_t, mode_t);
 int mbx_Xopen (char *, uid_t, gid_t, mode_t, int *);
 int mbx_read (FILE *, long, struct drop **, int);
-int mbx_write(char *, int, FILE *, int, long, long, long, int, int);
+int mbx_write(char *, int, FILE *, int, long, long, off_t, int, int);
 int mbx_copy (char *, int, int, int, char *, int);
-int mbx_size (int, long, long);
+int mbx_size (int, off_t, off_t);
 int mbx_close (char *, int);
 char *map_name (char *);
 int map_read (char *, long, struct drop **, int);
-int map_write (char *, int, int, long, long, long, long, int, int);
+int map_write (char *, int, int, long, off_t, off_t, long, int, int);
 int map_chk (char *, int, struct drop *, long, int);
 
