@@ -164,11 +164,11 @@ extern char *msg_delim;		/*  .. */
 /*
  * should be in <stdio.h>
  */
-#if !defined(SYS5) && !defined(_AIX) && !defined(OSF1) && !defined(BSD44)
-typedef struct _iobuf *FP;
-#else /* SYS5 */
+#if defined(SYS5) || defined(_AIX) || defined(OSF1) || defined(BSD44)
 # define FP FILE*
-#endif /* SYS5 */
+#else
+typedef struct _iobuf *FP;
+#endif
 
 /*
  * miscellaneous macros
