@@ -409,13 +409,13 @@ rclient (char *server, char *protocol, char *service)
     sm_ierror ("%s", response);
     return NOTOK;
 }
-#endif	/* SMTP */
+#endif /* SMTP */
 
 
 int
 sm_winit (int mode, char *from)
 {
-#ifdef	MPOP
+#ifdef MPOP
     if (sm_ispool && !sm_wfp) {
 	strlen (strcpy (sm_reply.text,
 			       "unable to create new spool file"));
@@ -442,7 +442,7 @@ sm_winit (int mode, char *from)
 }
 
 
-#ifdef	BERK
+#ifdef BERK
 /* ARGUSED */
 #endif	/* BERK */
 
@@ -453,9 +453,9 @@ sm_wadr (char *mbox, char *host, char *path)
     switch (smtalk (SM_RCPT, host && *host ? "RCPT TO:<%s%s@%s>"
 					   : "RCPT TO:<%s%s>",
 			     path ? path : "", mbox, host)) {
-#else	/* BERK */
+#else /* BERK */
     switch (smtalk (SM_RCPT, "RCPT TO:%s", mbox)) {
-#endif	/* BERK */
+#endif /* BERK */
 	case 250: 
 	case 251: 
 	    sm_addrs++;
@@ -699,7 +699,7 @@ losing0: ;
 	goto losing0;
     }
 
-    if ((cp = malloc ((unsigned) (cc = (pos = ftell (fp)) + 1))) == NULL) {
+    if ((cp = malloc ((size_t) (cc = (pos = ftell (fp)) + 1))) == NULL) {
 	sm_reply.length = strlen (strcpy (sm_reply.text, "out of memory"));
 losing1: ;
 	sm_reply.code = NOTOK;
@@ -848,16 +848,15 @@ bad_data: ;
     free (cp);
 
     {
+#ifdef HAVE_ST_BLKSIZE
 	struct stat st;
 
-#ifdef SYS5
-	cc = BUFSIZ;
-#else
-	if (fstat (fileno (sm_wfp), &st) == NOTOK
-	        || (cc = st.st_blksize) < BUFSIZ)
+	if (fstat (fileno (sm_wfp), &st) == NOTOK || (cc = st.st_blksize) < BUFSIZ)
 	    cc = BUFSIZ;
+#else
+	cc = BUFSIZ;
 #endif
-	if ((cp = malloc ((unsigned) cc)) == NULL) {
+	if ((cp = malloc ((size_t) cc)) == NULL) {
 	    smtalk (SM_RSET, "RSET");
 	    sm_reply.length = strlen (strcpy (sm_reply.text, "out of memory"));
 	    goto losing1;
@@ -1006,7 +1005,7 @@ smtalk (int time, char *fmt, ...)
 	fflush (stdout);
     }
 
-#ifdef	MPOP
+#ifdef MPOP
     if (sm_ispool) {
 	char    file[BUFSIZ];
 
@@ -1213,7 +1212,7 @@ again: ;
 	    if (doingEHLO == 2) {
 		int	len = strlen (buffer + 4);
 
-		if ((*ehlo = malloc ((unsigned) (strlen (buffer + 4) + 1)))) {
+		if ((*ehlo = malloc ((size_t) (strlen (buffer + 4) + 1)))) {
 		    strcpy (*ehlo++, buffer + 4);
 		    *ehlo = NULL;
 		    if (ehlo >= EHLOkeys + MAXEHLO)
