@@ -17,13 +17,18 @@
 # endif
 #endif
 
+#ifdef SCO_5_STDIO
+# define _ptr  __ptr
+# define _cnt  __cnt
+# define _base __base
+# define _filbuf(fp)  ((fp)->__cnt = 0, __filbuf(fp))
+#endif
+
 
 void
 discard (FILE *io)
 {
-#ifdef HAVE_TERMIOS_H
-    struct termios tio;
-#else
+#ifndef HAVE_TERMIOS_H
 # ifdef HAVE_TERMIO_H
     struct termio tio;
 # else
