@@ -279,8 +279,7 @@ static char *lmonth[] = { "January",  "February","March",   "April",
 static char *
 get_x400_friendly (char *mbox, char *buffer)
 {
-    char    given[BUFSIZ],
-	    surname[BUFSIZ];
+    char given[BUFSIZ], surname[BUFSIZ];
 
     if (mbox == NULL)
 	return NULL;
@@ -336,7 +335,7 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
     register struct tws *tws;
     register struct mailname *mn;
     int ljust;
-    long l;
+    time_t t;
     char *savestr;
     char buffer[BUFSIZ];
 
@@ -727,17 +726,17 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
 
 	case FT_LOCALDATE:
 	    comp = fmt->f_comp;
-	    if ((l = comp->c_tws->tw_clock) == 0)
-		l = twclock(comp->c_tws);
-	    tws = dlocaltime(&l);
+	    if ((t = comp->c_tws->tw_clock) == 0)
+		t = twclock(comp->c_tws);
+	    tws = dlocaltime(&t);
 	    *comp->c_tws = *tws;
 	    break;
 
 	case FT_GMTDATE:
 	    comp = fmt->f_comp;
-	    if ((l = comp->c_tws->tw_clock) == 0)
-		l = twclock(comp->c_tws);
-	    tws = dgmtime(&l);
+	    if ((t = comp->c_tws->tw_clock) == 0)
+		t = twclock(comp->c_tws);
+	    tws = dgmtime(&t);
 	    *comp->c_tws = *tws;
 	    break;
 
