@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 
 extern int errno;
