@@ -160,19 +160,26 @@ extern int msg_style;	/* defined in sbr/m_msgdef.c = MS_DEFAULT */
  * is used in m_Eom because the first character of the string
  * has been read and matched before m_Eom is called.
  */
-extern char *msg_delim;	/*  defined in sbr/m_msgdef.c = "" */
+extern char *msg_delim;         /* defined in sbr/m_msgdef.c = "" */
 static unsigned char *fdelim;
 static unsigned char *delimend;
-static int  fdelimlen;
+static int fdelimlen;
 static unsigned char *edelim;
-static int  edelimlen;
+static int edelimlen;
 
 static int (*eom_action)() = NULL;
 
 #ifdef _FSTDIO
-#define	_ptr	_p		/* Gag */
-#define	_cnt	_r		/* Retch */
-#define	_filbuf	__srget		/* Puke */
+# define _ptr    _p		/* Gag   */
+# define _cnt    _r		/* Retch */
+# define _filbuf __srget	/* Puke  */
+#endif
+
+#ifdef SCO_5_STDIO
+# define _ptr  __ptr
+# define _cnt  __cnt
+# define _base __base
+# define _filbuf(fp)  ((fp)->__cnt = 0, __filbuf(fp))
 #endif
 
 
@@ -417,8 +424,8 @@ finish:;
 }
 
 
-#ifdef	RPATHS
-static char  unixbuf[BUFSIZ] = "";
+#ifdef RPATHS
+static char unixbuf[BUFSIZ] = "";
 #endif /* RPATHS */
 
 void
@@ -525,7 +532,7 @@ m_Eom (int c, FILE *iob)
     register long pos = 0L;
     register int i;
     char text[10];
-#ifdef	RPATHS
+#ifdef RPATHS
     register char *cp;
 #endif /* RPATHS */
 
@@ -538,7 +545,7 @@ m_Eom (int c, FILE *iob)
 	     */
 	    return 1;
 
-#ifdef	notdef
+#ifdef notdef
 	fseek (iob, pos, 0);
 #else
 	fseek (iob, (long)(pos-1), 0);
@@ -548,7 +555,7 @@ m_Eom (int c, FILE *iob)
     }
 
     if (msg_style == MS_UUCP) {
-#ifndef	RPATHS
+#ifndef RPATHS
 	while ((c = getc (iob)) != '\n')
 	    if (c < 0)
 		break;
