@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 void
@@ -14,9 +14,9 @@ m_replace (char *key, char *value)
     register struct node *np;
 
     m_getdefs ();
-    if (m_defs == NULL) {
+    if (!m_defs) {
 	np = m_defs = (struct node *) malloc (sizeof *np);
-	if (np == NULL)
+	if (!np)
 	    adios (NULL, "unable to allocate profile storage");
 
 	np->n_name = getcpy (key);
@@ -29,7 +29,7 @@ m_replace (char *key, char *value)
 
     for (np = m_defs;; np = np->n_next) {
 	if (uleq (np->n_name, key)) {
-	    if (strcmp (value, np->n_field) != 0) {
+	    if (strcmp (value, np->n_field)) {
 		if (!np->n_context)
 		    admonish (NULL, "bug: m_replace(key=\"%s\",value=\"%s\")", key, value);
 		if (np->n_field)
@@ -42,8 +42,8 @@ m_replace (char *key, char *value)
 	if (!np->n_next)
 	    break;
     }
-    np->n_next = (struct node *) malloc (sizeof *np);
-    if (np->n_next == NULL)
+    np->n_next = (struct node *) malloc (sizeof(*np));
+    if (!np->n_next)
 	adios (NULL, "unable to allocate profile storage");
 
     np = np->n_next;
