@@ -5,21 +5,19 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 char *
 m_seqbits (struct msgs *mp)
 {
-    int bits;
-    register int i;
+    int i;
     static char buffer[BUFSIZ];
 
-    bits = FFATTRSLOT;
     strcpy (buffer, MBITS);
     for (i = 0; mp->msgattrs[i]; i++)
 	sprintf (buffer + strlen (buffer), "%c%s",
-		bits + i + 1, mp->msgattrs[i]);
+		FFATTRSLOT + 1 + i, mp->msgattrs[i]);
 
     return buffer;
 }
