@@ -477,8 +477,8 @@ char   *vec[];
     register struct bboard *bb;
 
     vec[0] = r1bindex (mshproc, '/');
-#ifdef	SIGTSTP
-    tstat = signal (SIGTSTP, tstpser);
+#ifdef SIGTSTP
+    tstat = SIGNAL (SIGTSTP, tstpser);
 #endif	SIGTSTP
 
     for (bb = bbl; bb && !quitting; bb = bb->bb_link) {
@@ -506,15 +506,13 @@ char   *vec[];
 	}
     };
 
-#ifdef	SIGTSTP
-    signal (SIGTSTP, tstat);
-#endif	SIGTSTP
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, tstat);
+#endif
     rcend ();
 }
 
-/*  */
-
-#ifdef	BPOP
+#ifdef BPOP
 /* ARGSUSED */
 
 static int  xtnd1 (s)
@@ -631,22 +629,22 @@ register struct bboard  *bb;
     char    buffer[BUFSIZ];
     struct bbcount *selected;
 
-    estat = signal (SIGEMT, sigser);
-    hstat = signal (SIGHUP, hupser);
-    istat = signal (SIGINT, SIG_IGN);
-    qstat = signal (SIGQUIT, SIG_IGN);
-    tstat = signal (SIGTERM, sigser);
+    estat = SIGNAL (SIGEMT, sigser);
+    hstat = SIGNAL (SIGHUP, hupser);
+    istat = SIGNAL (SIGINT, SIG_IGN);
+    qstat = SIGNAL (SIGQUIT, SIG_IGN);
+    tstat = SIGNAL (SIGTERM, sigser);
 
     while ((n = read (pd, buffer, sizeof buffer)) == NOTOK && errno == EINTR)
 	continue;
     close (pd);
     pidXwait (child_id, mshproc);
 
-    signal (SIGEMT, estat);
-    signal (SIGHUP, hstat);
-    signal (SIGINT, istat);
-    signal (SIGQUIT, qstat);
-    signal (SIGTERM, tstat);
+    SIGNAL (SIGEMT, estat);
+    SIGNAL (SIGHUP, hstat);
+    SIGNAL (SIGINT, istat);
+    SIGNAL (SIGQUIT, qstat);
+    SIGNAL (SIGTERM, tstat);
 
     if (n <= 0)
 	return;
@@ -675,27 +673,24 @@ register struct bboard  *bb;
 }
 
 
-/* ARGSUSED */
-
-RETSIGTYPE	sigser (i)
-int     i;
+RETSIGTYPE
+sigser (int i)
 {
-#ifndef	BSD42
-    signal (i, sigser);
-#endif	not BSD42
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (i, sigser);
+#endif
+
     quitting++;
 }
 
 
-/* ARGSUSED */
-
-RETSIGTYPE	hupser (i)
-int	i;
+RETSIGTYPE
+hupser (int i)
 {
     static int armed = 0;
 
-#ifndef	BSD42
-    signal (i, hupser);
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (i, hupser);
 #endif
 
     if (!armed++)		/* tick tock... */
@@ -751,19 +746,20 @@ register char  *rc;
     fclose (bbrc);
 }
 
-/*  */
 
-rcend () {
+rcend (void)
+{
     SIGNAL_HANDLER hstat, istat, qstat, tstat;
     register FILE *bbrc;
 
     if (!changed)
 	return;
 
-    hstat = signal (SIGHUP, SIG_IGN);
-    istat = signal (SIGINT, SIG_IGN);
-    qstat = signal (SIGQUIT, SIG_IGN);
-    tstat = signal (SIGTERM, SIG_IGN);
+    /* should be changed to block instead of ignore */
+    hstat = SIGNAL (SIGHUP, SIG_IGN);
+    istat = SIGNAL (SIGINT, SIG_IGN);
+    qstat = SIGNAL (SIGQUIT, SIG_IGN);
+    tstat = SIGNAL (SIGTERM, SIG_IGN);
 
     if ((bbrc = fopen (rcfile, "w")) == NULL)
 	adios (rcfile, "unable to write");
@@ -773,10 +769,10 @@ rcend () {
 	adios (rcfile, "error writing");
     fclose (bbrc);
 
-    signal (SIGHUP, hstat);
-    signal (SIGINT, istat);
-    signal (SIGQUIT, qstat);
-    signal (SIGTERM, tstat);
+    SIGNAL (SIGHUP, hstat);
+    SIGNAL (SIGINT, istat);
+    SIGNAL (SIGQUIT, qstat);
+    SIGNAL (SIGTERM, tstat);
 
     changed = 0;
 }
@@ -816,19 +812,21 @@ int	sig;
 	continue;
 #endif
 
-    signal (SIGTSTP, SIG_DFL);
-#ifdef	BSD42
+    SIGNAL (SIGTSTP, SIG_DFL);
+
+#ifdef BSD42
     sigsetmask (sigblock (0) & ~sigmask (SIGTSTP));
-#endif	BSD42
+#endif
 
     kill (getpid (), sig);
 
-#ifdef	BSD42
+#ifdef BSD42
     sigblock (sigmask (SIGTSTP));
-#endif	BSD42
-    signal (SIGTSTP, tstpser);
+#endif
+
+    SIGNAL (SIGTSTP, tstpser);
 }
-#endif	SIGTSTP
+#endif /* SIGTSTP */
 
 
 static	void	bbreset (bb, i)
