@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static struct swit switches[] = {
 #define	DFOLDSW                0
@@ -86,7 +86,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -209,11 +209,11 @@ main (int argc, char **argv)
     }
     else
 	if (form) {
-	    if ((in = open (libpath (form), 0)) == NOTOK)
+	    if ((in = open (etcpath (form), 0)) == NOTOK)
 		adios (form, "unable to open form file");
 	}
 	else {
-	    if ((in = open (libpath (components), 0)) == NOTOK)
+	    if ((in = open (etcpath (components), 0)) == NOTOK)
 		adios (components, "unable to open default components file");
 	    form = components;
 	}
