@@ -17,11 +17,14 @@
 # include "mmdfonly.h"
 #endif
 
-#include <errno.h>
+#ifdef HAVE_ERRNO_H
+# include <errno.h>
+#endif
 
 #ifdef NTOHLSWAP
 # include <netinet/in.h>
 #else
+# undef ntohl
 # define ntohl(n) (n)
 #endif
 
@@ -96,8 +99,8 @@ mbx_Xopen (char *file, uid_t uid, gid_t gid, mode_t mode, int *clear)
     int	count, fd;
     struct stat st;
 
-    for (*clear = 0, count = 4, j = 0; count > 0; count--)
-	if ((fd = lkopen (file, 6)) == NOTOK)
+    for (*clear = 0, count = 4, j = 0; count > 0; count--) {
+	if ((fd = lkopen (file, 6)) == NOTOK) {
 	    switch (errno) {
 		case ENOENT: 
 		    if (mbx_create (file, uid, gid, mode) == NOTOK)
@@ -105,9 +108,13 @@ mbx_Xopen (char *file, uid_t uid, gid_t gid, mode_t mode, int *clear)
 		    (*clear)++;
 		    break;
 
-#ifdef	BSD42
+#if defined(FCNTL) || defined(LOCKF)
+		case EACCES:
+		case EAGAIN:
+#endif
+#ifdef FLOCK
 		case EWOULDBLOCK:
-#endif	/* BSD42 */
+#endif
 		case ETXTBSY: 
 		    j = errno;
 		    sleep (5);
@@ -116,10 +123,11 @@ mbx_Xopen (char *file, uid_t uid, gid_t gid, mode_t mode, int *clear)
 		default: 
 		    return NOTOK;
 	    }
-	else {
-	    *clear = fstat (fd, &st) != NOTOK && st.st_size == (off_t)0;
+	} else {
+	    *clear = fstat (fd, &st) != NOTOK && st.st_size == (off_t) 0;
 	    break;
 	}
+    }
 
     errno = j;
     return fd;
