@@ -1,6 +1,6 @@
 
 /*
- * folder(s).c -- report on folders
+ * folder(s).c -- set/list the current folder/message
  *
  * $Id$
  */
@@ -232,10 +232,15 @@ main (int argc, char **argv)
 	printsw++;
     if (pushsw) {
 	if (!argfolder) {
-	    if ((cp = m_find (stack)) == NULL
-		    || (ap = brkstring (dp = getcpy (cp), " ", "\n")) == NULL
-		    || (argfolder = *ap++) == NULL)
+	    /* If no folder is given, the current folder and */
+	    /* the top of the folder stack are swapped.      */
+	    if ((cp = m_find (stack))) {
+		dp = getcpy (cp);
+		ap = brkstring (dp, " ", "\n");
+		argfolder = getcpy(*ap++);
+	    } else {
 		adios (NULL, "no other folder");
+	    }
 	    for (cp = getcpy (m_getfolder ()); *ap; ap++)
 		cp = add (*ap, add (" ", cp));
 	    free (dp);
@@ -250,17 +255,24 @@ main (int argc, char **argv)
     if (popsw) {
 	if (argfolder)
 	    adios (NULL, "sorry, no folders allowed with -pop");
-	if ((cp = m_find (stack)) == NULL
-		|| (ap = brkstring (dp = getcpy (cp), " ", "\n")) == NULL
-		|| (argfolder = *ap++) == NULL)
+	if ((cp = m_find (stack))) {
+	    dp = getcpy (cp);
+	    ap = brkstring (dp, " ", "\n");
+	    argfolder = getcpy(*ap++);
+	} else {
 	    adios (NULL, "folder stack empty");
-	for (cp = NULL; *ap; ap++)
-	    cp = cp ? add (*ap, add (" ", cp)) : getcpy (*ap);
-	free (dp);
-	if (cp)
+	}
+	if (*ap) {
+	    /* if there's anything left in the stack */
+	    cp = getcpy (*ap++);
+	    for (; *ap; ap++)
+		cp = add (*ap, add (" ", cp));
 	    m_replace (stack, cp);
-	else
+	} else {
+	    /* else just delete that entry */
 	    m_delete (stack);
+	}
+	free (dp);
     }
     if (pushsw || popsw) {
 	cp = m_maildir(argfolder);
@@ -272,8 +284,9 @@ main (int argc, char **argv)
     }
     if (listsw) {
 	printf ("%s", argfolder ? argfolder : m_getfolder ());
-	if (cp = m_find (stack)) {
-	    for (ap = brkstring (dp = getcpy (cp), " ", "\n"); *ap; ap++)
+	if ((cp = m_find (stack))) {
+	    dp = getcpy (cp);
+	    for (ap = brkstring (dp, " ", "\n"); *ap; ap++)
 		printf (" %s", *ap);
 	    free (dp);
 	}
@@ -338,7 +351,6 @@ main (int argc, char **argv)
     }
 
     m_update ();
-
     done (0);
 }
 
@@ -522,7 +534,7 @@ addir (char *name)
 	admonish (name, "unable to read directory ");
 	return;
     }
-    while (dp = readdir (dd))
+    while ((dp = readdir (dd)))
 	if (strcmp (dp->d_name, ".") && strcmp (dp->d_name, "..")) {
 	    if (cp + NLENGTH(dp) + 2 >= name + BUFSIZ)
 		continue;
@@ -563,7 +575,7 @@ compare (char *s1, char *s2)
     register int i;
 
     while (*s1 || *s2)
-	if (i = *s1++ - *s2++)
+	if ((i = *s1++ - *s2++))
 	    return i;
 
     return 0;
