@@ -1,6 +1,6 @@
 
 /*
- * install-mh.c -- initialize the MH environment
+ * install-mh.c -- initialize the nmh environment
  *
  * $Id$
  */
@@ -9,10 +9,10 @@
 #include <pwd.h>
 
 static char *message[] = {
-    "Prior to using MH, it is necessary to have a file in your login",
+    "Prior to using nmh, it is necessary to have a file in your login",
     "directory (%s) named %s which contains information",
-    "to direct certain MH operations.  The only item which is required",
-    "is the path to use for all MH folder operations.  The suggested MH",
+    "to direct certain nmh operations.  The only item which is required",
+    "is the path to use for all nmh folder operations.  The suggested nmh",
     "path for you is %s/Mail...",
     NULL
 };
@@ -58,7 +58,7 @@ main (int argc, char **argv)
 	    adios (NULL, "invocation error");
 	else
 	    adios (NULL,
-		    "You already have an MH profile, use an editor to modify it");
+		    "You already have an nmh profile, use an editor to modify it");
 
     if (!autof && gans ("Do you want help? ", anoyes)) {
 	putchar ('\n');
@@ -72,8 +72,8 @@ main (int argc, char **argv)
     cp = concat (mypath, "/", "Mail", NULL);
     if (stat (cp, &st) != NOTOK) {
 	if (S_ISDIR(st.st_mode)) {
-	    cp = concat ("You already have the standard MH directory \"",
-		    cp, "\".\nDo you want to use it for MH? ", NULL);
+	    cp = concat ("You already have the standard nmh directory \"",
+		    cp, "\".\nDo you want to use it for nmh? ", NULL);
 	    if (gans (cp, anoyes))
 		path = "Mail";
 	    else
@@ -84,9 +84,9 @@ main (int argc, char **argv)
     }
     else {
 	if (autof)
-	    printf ("I'm going to create the standard MH path for you.\n");
+	    printf ("I'm going to create the standard nmh path for you.\n");
 	else
-	    cp = concat ("Do you want the standard MH path \"",
+	    cp = concat ("Do you want the standard nmh path \"",
 		    mypath, "/", "Mail\"? ", NULL);
 	if (autof || gans (cp, anoyes))
 	    path = "Mail";
