@@ -5,7 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
+
 
 main (int argc, char **argv)
 {
@@ -15,6 +16,7 @@ main (int argc, char **argv)
     done (mhl (argc, argv));
 }
 
+
 /*
  * Cheat: we are loaded with adrparse, which wants a routine called
  * OfficialName().  We call adrparse:getm() with the correct arguments
