@@ -10,12 +10,6 @@
 #include <h/addrsbr.h>
 #include <h/formatsbr.h>
 #include <zotnet/tws/tws.h>
-
-#if defined(SYS5) && defined(AUX)
-# define u_short ushort
-# define u_long  ulong
-#endif
-
 #include <setjmp.h>
 #include <signal.h>
 
@@ -38,10 +32,6 @@
  * better chance of getting things right.
  */
 
-#ifdef SYS5
-# define u_short ushort
-#endif
-
 #define ONECOMP  0
 #define TWOCOMP  1
 #define	BODYCOMP 2
@@ -1477,12 +1467,12 @@ doface (struct mcomp *c1)
     static int inited = OK;
     static int addrlen;
     static struct in_addr addr;
-    static u_short portno;
+    static ushort portno;
 
     if (inited == OK) {
-	u_long	iaddr;
-	char   *cp;
-	char  **ap = brkstring (cp = getcpy (faceproc), " ", "\n");
+	ulong iaddr;
+	char *cp;
+	char **ap = brkstring (cp = getcpy (faceproc), " ", "\n");
 	struct hostent *hp;
 
 	if (ap[0] == NULL || ap[1] == NULL) {
@@ -1495,7 +1485,7 @@ bad_faceproc: ;
 	    goto bad_faceproc;
 	memcpy((char *) &addr, hp->h_addr, addrlen = hp->h_length);
 
-	portno = htons ((u_short) atoi (ap[1]));
+	portno = htons ((ushort) atoi (ap[1]));
 	free (cp);
 
 	inited = DONE;
