@@ -341,7 +341,7 @@ checkmail (char *user, char *home, int datesw, int notifysw, int personal)
     if (notifysw)
 	if (datesw && st.st_atime)
 	    printf ("; last read on %s",
-		    dasctime (dlocaltime ((long *) & st.st_atime), TW_NULL));
+		    dasctime (dlocaltime ((time_t *) &st.st_atime), TW_NULL));
 #endif	/* MF */
     if (notifysw)
 	printf ("\n");
