@@ -1060,8 +1060,8 @@ forw (char *proc, char *filter, int vecp, char **vec)
 
 
 static char *hlpmsg[] = {
-    "The %s program emulates many of the commands found in the Rand MH",
-    "system.  Instead of operating on MH folders, commands to %s concern",
+    "The %s program emulates many of the commands found in the nmh",
+    "system.  Instead of operating on nmh folders, commands to %s concern",
     "a single file.",
     "",
     "To see the list of commands available, just type a ``?'' followed by",
@@ -1069,15 +1069,15 @@ static char *hlpmsg[] = {
     "the name of the command followed by ``-help''.  To leave %s, use the",
     "``quit'' command.",
     "",
-    "Although a lot of MH commands are found in %s, not all are fully",
+    "Although a lot of nmh commands are found in %s, not all are fully",
     "implemented.  %s will always recognize all legal switches for a",
     "given command though, and will let you know when you ask for an",
     "option that it is unable to perform.",
     "",
-    "Running %s is fun, but using MH from your shell is far superior.",
-    "After you have familiarized yourself with the MH style by using %s,",
-    "you should try using MH from the shell.  You can still use %s for",
-    "message files that aren't in MH format, such as BBoard files.",
+    "Running %s is fun, but using nmh from your shell is far superior.",
+    "After you have familiarized yourself with the nmh style by using %s,",
+    "you should try using nmh from the shell.  You can still use %s for",
+    "message files that aren't in nmh format, such as BBoard files.",
     NULL
 };
 
