@@ -221,7 +221,7 @@ parse (void)
 	case PROR: 
 	    o = newnexus (ORaction);
 	    o->n_L_child = n;
-	    if (o->n_R_child = parse ())
+	    if ((o->n_R_child = parse ()))
 		return o;
 	    padvise (NULL, "missing disjunctive");
 	    return NULL;
@@ -262,7 +262,7 @@ exp1 (void)
 	case PRAND: 
 	    o = newnexus (ANDaction);
 	    o->n_L_child = n;
-	    if (o->n_R_child = exp1 ())
+	    if ((o->n_R_child = exp1 ()))
 		return o;
 	    padvise (NULL, "missing conjunctive");
 	    return NULL;
@@ -303,7 +303,7 @@ exp2 (void)
 
 	case PRNOT: 
 	    n = newnexus (NOTaction);
-	    if (n->n_L_child = exp3 ())
+	    if ((n->n_L_child = exp3 ()))
 		return n;
 	    padvise (NULL, "missing negation");
 	    return NULL;
@@ -839,7 +839,7 @@ static struct tws *
 tws_special (char *ap)
 {
     int i;
-    long clock;
+    time_t clock;
     register struct tws *tw;
 
     time (&clock);
