@@ -258,25 +258,25 @@ static struct mailname netaddrs={NULL};		/* network addrs */
 static struct mailname uuaddrs={NULL};		/* uucp addrs */
 static struct mailname tmpaddrs={NULL};		/* temporary queue */
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
 static char *submitmode = "m";	/* deliver to mailbox only */
 static char submitopts[6] = "vl";/* initial options for submit */
-#endif	/* MMDFMTS */
+#endif /* MMDFMTS */
 
-#ifdef	MHMTS
+#ifdef MHMTS
 static char *deliver = NULL;
 
 extern char **environ;
 #endif	/* MHMTS */
 
-#ifdef	SENDMTS
+#ifdef SENDMTS
 static int smtpmode = S_MAIL;
 static int snoop = 0;
 static char *clientsw = NULL;
 static char *serversw = NULL;
 
 extern struct smtp  sm_reply;
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
 #ifdef TMA
 # define post(a,b,c) \
@@ -295,15 +295,13 @@ static int encryptsw = 0;	/* encrypt it */
 #endif
 
 #ifdef MIME
-static char	prefix[] = "----- =_aaaaaaaaaa";
-static int      find_prefix();
+static char prefix[] = "----- =_aaaaaaaaaa";
 #endif
 
-static int	fill_up = 0;
-static char    *fill_in = NULL;
-static char    *partno = NULL;
-
-static	int	queued = 0;
+static int fill_up = 0;
+static char *fill_in = NULL;
+static char *partno = NULL;
+static int queued = 0;
 
 /*
  * prototypes
@@ -327,10 +325,8 @@ static void anno (void);
 static int annoaux (struct mailname *);
 static void insert_fcc (struct headers *, char *);
 static void make_bcc_file (void);
-static int find_prefix (void);
 static void verify_all_addresses (int);
 static void chkadr (void);
-static void postcipher (char *, int, int);
 static void do_text (char *file, int fd);
 static void do_an_address (struct mailname *, int, int);
 static void sigon (void);
@@ -339,6 +335,14 @@ static void p_refile (char *);
 static void fcc (char *, char *);
 static void die (char *, char *, ...);
 
+#ifdef MIME
+static int find_prefix (void);
+#endif
+
+#ifdef TMA
+static void postcipher (char *, int, int);
+#endif
+
 #ifdef TMA
 static void postplain (char *, int, int);
 #else   
@@ -1301,7 +1305,7 @@ make_bcc_file (void)
     }
 
     fseek (out, 0L, 2);
-#ifdef	MIME
+#ifdef MIME
     if (mime)
 	fprintf (out, "\n--%s--\n", prefix);
     else
@@ -1365,7 +1369,7 @@ verify_all_addresses (int talk)
     sigon ();
 #endif	/* not MHMTS */
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (!whomsw || checksw) {
 	if (rp_isbad (retval = mm_init ())
 		|| rp_isbad (retval = mm_sbinit ())
@@ -1379,13 +1383,13 @@ verify_all_addresses (int talk)
 #endif	/* RP_NS */
     }
 #endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#ifdef SENDMTS
     if (!whomsw || checksw)
 	if (rp_isbad (retval = sm_init (clientsw, serversw, 0, 0, snoop, 0, 0))
 		|| rp_isbad (retval = sm_winit (smtpmode, from)))
 	    die (NULL, "problem initializing server; %s",
 		    rp_string (retval));
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
     if (talk && !whomsw)
 	printf (" -- Address Verification --\n");
@@ -1636,12 +1640,12 @@ do_a_cipher (struct mailname *lp, int talk)
 		    rp_valstr (retval));
 #endif	/* RP_NS */
 #endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#ifdef SENDMTS
     if (rp_isbad (retval = sm_init (clientsw, serversw, watch, verbose, snoop,
 				    0, 0))
 	    || rp_isbad (retval = sm_winit (smtpmode, from)))
 	die (NULL, "problem initializing server; %s", rp_string (retval));
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
     do_an_address (lp, talk, 0);
 
@@ -1764,7 +1768,7 @@ do_addresses (char *file, int fd, int ud, int bccque, int talk)
 #endif	/* not BERK */
 #ifndef	MHMTS
 	    do_an_address (lp, talk, 0);
-#else	/* MHMTS */
+#else /* MHMTS */
 	    netmail (talk, fd, bccque);
 #endif	/* MHMTS */
 #ifndef	BERK
@@ -1859,7 +1863,7 @@ do_text (char *file, int fd)
 
 /* MTS-SPECIFIC INTERACTION */
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
 
 static void
 do_an_address (struct mailname *lp, int talk, int tma)
@@ -2224,7 +2228,7 @@ p_refile (char *file)
     if (fccind == 0)
 	return;
 
-#ifdef	MHMTS
+#ifdef MHMTS
     setuid (myuid);
 #endif	/* MHMTS */
     if (verbose)
@@ -2286,18 +2290,18 @@ die (char *what, char *fmt, ...)
 {
     va_list ap;
 
-#ifndef	MHMTS
+#ifndef MHMTS
     unlink (tmpfil);
     if (msgflags & MINV)
 	unlink (bccfil);
 #endif	/* MHMTS */
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (!whomsw || checksw)
 	mm_end (NOTOK);
 #endif	/* MMDFMTS */
 
-#ifdef	SENDMTS
+#ifdef SENDMTS
     if (!whomsw || checksw)
 	sm_end (NOTOK);
 #endif	/* SENDMTS */
@@ -2309,7 +2313,7 @@ die (char *what, char *fmt, ...)
 }
 
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
 /* 
  *    err_abrt() is used by the mm_ routines
  *    		 do not, under *ANY* circumstances, remove it from post,
@@ -2334,7 +2338,7 @@ err_abrt (int code, char *fmt, ...)
 
 /* STAND-ALONE DELIVERY */
 
-#ifdef	MHMTS
+#ifdef MHMTS
 
 /* BUG: MHMTS ignores 822-style route addresses... */
 
@@ -2443,12 +2447,12 @@ usr_hook (struct mailname *lp, int talk, int fd, struct home *hp, char *mailbox)
 	    if (fd != 3)	/* backwards compatible... */
 		dup2 (fd, 3);
 	    closefds (4);
-#ifdef	TIOCNOTTY
+#ifdef TIOCNOTTY
 	    if ((fd = open ("/dev/tty", 2)) != NOTOK) {
 		ioctl (fd, TIOCNOTTY, NULL);
 		close (fd);
 	    }
-#endif	/* TIOCNOTTY */
+#endif /* TIOCNOTTY */
 #ifdef BSD42
 	    setpgrp (0, getpid ());
 #endif /* BSD42 */
@@ -2625,9 +2629,8 @@ make_uucp_file (int td)
 static void
 netmail (int talk, int fd, int bccque)
 {
-    int     i,
-            naddrs;
-    char    buffer[BUFSIZ];
+    int i, naddrs;
+    char buffer[BUFSIZ];
     register struct mailname *lp;
 
     naddrs = 0;
