@@ -190,10 +190,10 @@ main (int argc, char **argv)
     chmod (tmpfil, 0600);
 
     if (killp || erasep) {
-#ifdef SYS5
-	char serase, skill;
+#ifdef HAVE_TERMIOS_H
+	cc_t save_erase, save_kill;
 #else
-	int serase, skill;
+	int save_erase, save_kill;
 #endif
 
 /* get the terminal attributes */
@@ -208,10 +208,10 @@ main (int argc, char **argv)
 # endif
 #endif
 
-	skill = KILL;
-	serase = ERASE;
-	KILL = killp ? chrcnv (killp) : skill;
-	ERASE = erasep ? chrcnv (erasep) : serase;
+	save_kill = KILL;
+	save_erase = ERASE;
+	KILL = killp ? chrcnv (killp) : save_kill;
+	ERASE = erasep ? chrcnv (erasep) : save_erase;
 
 #ifdef HAVE_TERMIOS_H
 	 tcsetattr(0, TCSADRAIN, &tio);
@@ -229,8 +229,8 @@ main (int argc, char **argv)
 	putchar ('\n');
 	fflush (stdout);
 
-	KILL = skill;
-	ERASE = serase;
+	KILL = save_kill;
+	ERASE = save_erase;
     }
 
     sigint = 0;
