@@ -192,7 +192,7 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 	switch (state = m_getfld (state, name, tmpbuf, SBUFSIZ, inb)) {
 	    case FLD: 
 	    case FLDPLUS: 
-		if (cptr = wantcomp[CHASH (name)])
+		if ((cptr = wantcomp[CHASH (name)]))
 		    do {
 			if (uleq (name, cptr->c_name)) {
 			    char_read += msg_count;
@@ -220,7 +220,7 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 			    }
 			    break;
 			}
-		    } while (cptr = cptr->c_next);
+		    } while ((cptr = cptr->c_next));
 
 		while (state == FLDPLUS)
 		    state = m_getfld (state, name, tmpbuf, SBUFSIZ, inb);
