@@ -5,113 +5,98 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static struct swit switches[] = {
-#define	ANNOSW	0
-    "annotate", 0,
-#define	NANNOSW	1
-    "noannotate", 0,
+#define	ANNOSW                 0
+    { "annotate", 0 },
+#define	NANNOSW                1
+    { "noannotate", 0 },
+#define	CCSW                   2
+    { "cc type", 0 },
+#define	NCCSW                  3
+    { "nocc type", 0 },
+#define	DFOLDSW                4
+    { "draftfolder +folder", 0 },
+#define	DMSGSW                 5
+    { "draftmessage msg", 0 },
+#define	NDFLDSW                6
+    { "nodraftfolder", 0 },
+#define	EDITRSW                7
+    { "editor editor", 0 },
+#define	NEDITSW                8
+    { "noedit", 0 },
+#define	FCCSW                  9
+    { "fcc folder", 0 },
+#define	FILTSW                10
+    { "filter filterfile", 0 },
+#define	FORMSW                11
+    { "form formfile", 0 },
+#define	FRMTSW                12
+    { "format", -5 },
+#define	NFRMTSW               13
+    { "noformat", -7 },
+#define	INPLSW                14
+    { "inplace", 0 },
+#define	NINPLSW               15
+    { "noinplace", 0 },
+#define	QURYSW                16
+    { "query", 0 },
+#define	NQURYSW               17
+    { "noquery", 0 },
+#define	WHATSW                18
+    { "whatnowproc program", 0 },
+#define	NWHATSW               19
+    { "nowhatnowproc", 0 },
+#define	WIDTHSW               20
+    { "width columns", 0 },
+#define VERSIONSW             21
+    { "version", 0 },
+#define	HELPSW                22
+    { "help", 4 },
+#define	FILESW                23
+    { "file file", -4 },		/* interface from msh */
 
-#define	CCSW	2
-    "cc type", 0,
-#define	NCCSW	3
-    "nocc type", 0,
+#ifdef MHE
+#define	BILDSW                24
+    { "build", -5 },			/* interface from mhe */
+#endif
 
-#define	DFOLDSW	4
-    "draftfolder +folder", 0,
-#define	DMSGSW	5
-    "draftmessage msg", 0,
-#define	NDFLDSW	6
-    "nodraftfolder", 0,
-
-#define	EDITRSW	7
-    "editor editor", 0,
-#define	NEDITSW	8
-    "noedit", 0,
-
-#define	FCCSW	9
-    "fcc folder", 0,
-
-#define	FILTSW	10
-    "filter filterfile", 0,
-#define	FORMSW	11
-    "form formfile", 0,
-
-#define	FRMTSW	12
-    "format", -5,
-#define	NFRMTSW	13
-    "noformat", -7,
-
-#define	INPLSW	14
-    "inplace", 0,
-#define	NINPLSW	15
-    "noinplace", 0,
-
-#define	QURYSW	16
-    "query", 0,
-#define	NQURYSW	17
-    "noquery", 0,
-
-#define	WHATSW	18
-    "whatnowproc program", 0,
-#define	NWHATSW	19
-    "nowhatnowproc", 0,
-
-#define	WIDTHSW	20
-    "width columns", 0,
-
-#define VERSIONSW 21
-    "version", 0,
-#define	HELPSW	22
-    "help", 4,
-
-#define	FILESW	23
-    "file file", -4,		/* interface from msh */
-
-#ifdef	MHE
-#define	BILDSW	24
-    "build", -5,		/* interface from mhe */
-#endif	/* MHE */
-
-    NULL, 0
+    { NULL, 0 }
 };
 
 static struct swit ccswitches[] = {
 #define	CTOSW	0
-    "to", 0,
+    { "to", 0 },
 #define	CCCSW	1
-    "cc", 0,
+    { "cc", 0 },
 #define	CMESW	2
-    "me", 0,
+    { "me", 0 },
 #define	CALSW	3
-    "all", 0,
-
-    NULL, 0
+    { "all", 0 },
+    { NULL, 0 }
 };
 
 static struct swit aqrnl[] = {
-#define	NOSW	0
-    "quit", 0,
-#define	YESW	1
-    "replace", 0,
-#define	LISTDSW	2
-    "list", 0,
-#define	REFILSW	3
-    "refile +folder", 0,
-#define NEWSW	4
-    "new", 0,
-
-    NULL, 0
+#define	NOSW         0
+    { "quit", 0 },
+#define	YESW         1
+    { "replace", 0 },
+#define	LISTDSW      2
+    { "list", 0 },
+#define	REFILSW      3
+    { "refile +folder", 0 },
+#define NEWSW        4
+    { "new", 0 },
+    { NULL, 0 }
 };
 
 static struct swit aqrl[] = {
-    "quit", 0,
-    "replace", 0,
-    "list", 0,
-    "refile +folder", 0,
-
-    NULL, 0
+    { "quit", 0 },
+    { "replace", 0 },
+    { "list", 0 },
+    { "refile +folder", 0 },
+    { NULL, 0 }
 };
 
 #ifndef	ATHENA
@@ -120,16 +105,16 @@ static struct swit aqrl[] = {
 # define CCDFLT	0
 #endif
 
-short   ccto = CCDFLT;		/* global for replsbr */
-short   cccc = CCDFLT;
-short   ccme = CCDFLT;
-short   format = 1;
-short   outputlinelen = OUTPUTLINELEN;
-short   querysw = 0;
+short ccto = CCDFLT;		/* global for replsbr */
+short cccc = CCDFLT;
+short ccme = CCDFLT;
+short format = 1;
+short outputlinelen = OUTPUTLINELEN;
+short querysw = 0;
 
-char   *fcc = NULL;		/* global for replsbr */
-char   *filter = NULL;
-char   *form = NULL;
+char *fcc = NULL;		/* global for replsbr */
+char *filter = NULL;
+char *form = NULL;
 
 /*
  * prototypes
@@ -140,30 +125,19 @@ void docc (char *, int);
 main (int argc, char **argv)
 {
     int	i, isdf = 0;
-    int anot = 0, inplace = 0,
-#ifdef	MHE
-	    buildsw = 0,
-#endif	/* MHE */
-	    nedit = 0,
-	    nwhat = 0;
-    char   *cp,
-	   *cwd,
-	   *dp,
-           *maildir,
-           *file = NULL,
-           *folder = NULL,
-           *msg = NULL,
-	   *dfolder = NULL,
-	   *dmsg = NULL,
-	   *ed = NULL,
-	    drft[BUFSIZ],
-            buf[100],
-          **ap,
-          **argp,
-           *arguments[MAXARGS];
+    int anot = 0, inplace = 0;
+    int nedit = 0, nwhat = 0;
+    char *cp, *cwd, *dp, *maildir, *file = NULL;
+    char *folder = NULL, *msg = NULL, *dfolder = NULL;
+    char *dmsg = NULL, *ed = NULL, drft[BUFSIZ], buf[100];
+    char **ap, **argp, *arguments[MAXARGS];
     struct msgs *mp = NULL;
     struct stat st;
-    FILE        *in;
+    FILE *in;
+
+#ifdef MHE
+    int buildsw = 0;
+#endif /* MHE */
 
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
@@ -178,7 +152,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -258,7 +232,7 @@ main (int argc, char **argv)
 		case FILTSW:
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-		    filter = getcpy (libpath (cp));
+		    filter = getcpy (etcpath (cp));
 		    continue;
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
