@@ -60,7 +60,7 @@ main (int argc, char **argv)
     int state, width = 0, msgp = 0, msgnum;
     int revflag = 0; 		/* used to be #ifdef BERK */
     int bits;			/* should match mp->msgstats[] type */
-    long clock;
+    time_t clock;
     char *cp, *maildir, *file = NULL, *folder = NULL;
     char *form = NULL, *format = NULL, buf[100], **ap;
     char **argp, *nfs, *arguments[MAXARGS], *msgs[MAXARGS];
@@ -230,7 +230,7 @@ main (int argc, char **argv)
 
     ontty = isatty (fileno (stdout));
 
-#ifdef	LBL
+#ifdef LBL
     else
 	fmt_current_folder = mp;
 #endif
@@ -240,24 +240,24 @@ main (int argc, char **argv)
 	    msgnum += revflag ? (-1) : 1)
 	if (mp->msgstats[msgnum] & SELECTED) {
 	    if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
-#ifdef	notdef
+#ifdef notdef
 		if (errno != EACCES)
 #endif
 		    admonish (cp, "unable to open message");
-#ifdef	notdef
+#ifdef notdef
 		else
 		    printf ("%*d  unreadable\n", DMAXFOLDER, msgnum);
 #endif
 		continue;
 	    }
 
-#ifndef	JLR
+#ifndef JLR
 	    if (hdrflag) {
 		time (&clock);
 		printf ("Folder %-32s%s\n\n", folder,
 			dasctime (dlocaltime (&clock), TW_NULL));
 	    }
-#endif	/* JLR */
+#endif /* JLR */
 	    switch (state = scan (in, msgnum, 0, nfs, width,
 			msgnum == mp->curmsg,
 			mp->msgstats[msgnum] & bits,
@@ -271,7 +271,7 @@ main (int argc, char **argv)
 		    adios (NULL, "scan() botch (%d)", state);
 
 		case SCNEOF: 
-#ifdef	notdef
+#ifdef notdef
 		    printf ("%*d  empty\n", DMAXFOLDER, msgnum);
 #else
 		    advise (NULL, "message %d: empty", msgnum);
@@ -283,11 +283,10 @@ main (int argc, char **argv)
 	    if (ontty)
 		fflush (stdout);
 	}
-#ifdef	LBL
+#ifdef LBL
     m_sync (mp);	/* because formatsbr might have made changes */
 #endif
 
-
     if (clearflag)
 	clear_screen ();
 
