@@ -272,16 +272,11 @@ main (int argc, char **argv)
     umask (0077);
 
     if (geteuid() == 0) {
-
-#ifdef	BSD41A
-	inigrp (pw->pw_name, pw->pw_gid);
-#endif	/* BSD41A */
-
 	setgid (pw->pw_gid);
 
-#ifdef	BSD42
+#ifdef BSD42
 	initgroups (pw->pw_name, pw->pw_gid);
-#endif	/* BSD42 */
+#endif /* BSD42 */
 
 	setuid (pw->pw_uid);
     }
@@ -852,7 +847,7 @@ usr_file (int fd, char *mailbox, char *from)
 	return NOTOK;
     }
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
     if (mbx_copy (mailbox, md, fd, mapping, bp, verbose) == NOTOK) {
 	adorn ("", "error writing to:");
 	return NOTOK;
@@ -929,7 +924,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	printf ("\tdelivering to pipe \"%s\"", cmd);
 	fflush (stdout);
     }
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
 
     for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
 	sleep (5);
@@ -954,9 +949,9 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    }
 #endif /* TIOCNOTTY */
 
-#ifdef	BSD42
+#ifdef BSD42
 	    setpgrp (0, getpid ());
-#endif	/* BSD42 */
+#endif /* BSD42 */
 
 	    *environ = NULL;
 	    m_putenv ("USER", pw->pw_name);
@@ -1074,7 +1069,7 @@ you_lose: ;
 	    }
 	if (i == NOTOK)
 	    goto you_lose;
-	lseek (fd1, (off_t) 0, 0);
+	lseek (fd1, (off_t) 0, SEEK_SET);
 	return fd1;
     }
 
@@ -1150,7 +1145,7 @@ you_lose: ;
     }
     fclose (qfp);
 
-    lseek (fd1, (off_t) 0, 0);
+    lseek (fd1, (off_t) 0, SEEK_SET);
 
     return fd1;
 }
