@@ -8,11 +8,6 @@
 #include <h/mh.h>
 #include <zotnet/tws/tws.h>
 
-#if defined(SYS5) && defined(AUX)
-# define u_short ushort
-# define u_long  ulong
-#endif
-
 static struct swit switches[] = {
 #define DATESW                 0
      { "datefield field", 0 },
@@ -39,7 +34,7 @@ static struct swit switches[] = {
 
 struct smsg {
     int s_msg;
-    unsigned long s_clock;
+    time_t s_clock;
     char *s_subj;
 };
 
@@ -47,7 +42,7 @@ static struct smsg *smsgs;
 int nmsgs;
 
 char *subjsort = (char *) 0;    /* sort on subject if != 0 */
-u_long datelimit = 0;
+ulong datelimit = 0;
 int submajor = 0;		/* if true, sort on subject-major */
 int verbose;
 
@@ -399,7 +394,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 	    cp = subjcomp;
 	    cp2 = subjcomp;
 	    if (strcmp (subjsort, "subject") == 0)
-		while (c = *cp) {
+		while ((c = *cp)) {
 		    if (! isspace(c)) {
 			if(uprf(cp, "re:"))
 			    cp += 2;
@@ -411,7 +406,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 		    }
 		    cp++;
 		}
-	    while (c = *cp++) {
+	    while ((c = *cp++)) {
 		if (isalnum(c))
 		    *cp2++ = isupper(c) ? tolower(c) : c;
 
@@ -454,7 +449,7 @@ subsort (struct smsg **a, struct smsg **b)
 {
     register int i;
 
-    if (i = strcmp ((*a)->s_subj, (*b)->s_subj))
+    if ((i = strcmp ((*a)->s_subj, (*b)->s_subj)))
 	return (i);
 
     return (dsort (a, b));
@@ -465,7 +460,7 @@ txtsort (struct smsg **a, struct smsg **b)
 {
     register int i;
 
-    if (i = strcmp ((*a)->s_subj, (*b)->s_subj))
+    if ((i = strcmp ((*a)->s_subj, (*b)->s_subj)))
 	return (i);
     else if ((*a)->s_msg < (*b)->s_msg)
 	return (-1);
