@@ -12,7 +12,7 @@
 #include <h/mhn.h>
 #endif
 
-#ifndef	MIME
+#ifndef MIME
 # define MIMEminc(a) (a)
 #else
 # define MIMEminc(a)  0
@@ -68,7 +68,7 @@ static sendfile (char **, char *, int);
 static void sendit (char *, char **, char *, int);
 static int whomfile (char **, char *);
 
-#ifdef BSD42
+#ifdef HAVE_LSTAT
 static int copyf (char *, char *);
 #endif
 
@@ -245,12 +245,12 @@ editfile (char **ed, char **arg, char *file, int use,
     char *vec[MAXARGS];
     struct stat st;
 
-#ifdef BSD42
-#ifdef	notdef
+#ifdef HAVE_LSTAT
+    int	slinked;
+#if 0
     int oumask;	/* PJS: for setting permissions on symlinks. */
 #endif
-    int	slinked;
-#endif	/* BSD42 */
+#endif /* HAVE_LSTAT */
 
     /* set initial editor */
     if (!reedit) {
@@ -280,22 +280,23 @@ editfile (char **ed, char **arg, char *file, int use,
 
     if (altmsg) {
 	unlink (linkpath);
-#ifdef BSD42
+#ifdef HAVE_LSTAT
 	if (link (altpath, linkpath) == NOTOK) {
-#ifdef	notdef	/* I don't think permission on symlinks matters /JLR */
+#if 0
+	    /* I don't think permission on symlinks matters /JLR */
 	    oumask = umask(0044);	/* PJS: else symlinks are world 'r' */
 #endif
 	    symlink (altpath, linkpath);
-#ifdef	notdef
+#if 0
 	    umask(oumask);		/* PJS: else symlinks are world 'r' */
 #endif
 	    slinked = 1;
 	}
 	else
 	    slinked = 0;
-#else	/*  not BSD42 */
+#else /* not HAVE_LSTAT */
 	link (altpath, linkpath);
-#endif	/* not BSD42 */
+#endif /* not HAVE_LSTAT */
     }
 
     m_update ();
@@ -330,7 +331,7 @@ editfile (char **ed, char **arg, char *file, int use,
 	    _exit (-1);
 
 	default: 
-	    if (status = pidwait (pid, NOTOK)) {
+	    if ((status = pidwait (pid, NOTOK))) {
 #ifdef ATTVIBUG
 		if ((cp = r1bindex (*ed, '/'))
 			&& strcmp (cp, "vi") == 0
@@ -356,7 +357,7 @@ editfile (char **ed, char **arg, char *file, int use,
 	    }
 
 	    reedit++;
-#ifdef BSD42
+#ifdef HAVE_LSTAT
 	    if (altmsg
 		    && mp
 		    && (!mp->msgflags & READONLY)
@@ -369,7 +370,7 @@ editfile (char **ed, char **arg, char *file, int use,
 				&& (unlink (altpath) == NOTOK
 					|| link (linkpath, altpath) == NOTOK)))
 		advise (linkpath, "unable to update %s from", altmsg);
-#else	/* not BSD42 */
+#else /* HAVE_LSTAT */
 	    if (altmsg
 		    && mp
 		    && (!mp->msgflags & READONLY)
@@ -378,7 +379,7 @@ editfile (char **ed, char **arg, char *file, int use,
 		    && (unlink (altpath) == NOTOK
 			|| link (linkpath, altpath) == NOTOK))
 		advise (linkpath, "unable to update %s from", altmsg);
-#endif	/* not BSD42 */
+#endif /* HAVE_LSTAT */
     }
 
     edsave = getcpy (*ed);
@@ -390,7 +391,7 @@ editfile (char **ed, char **arg, char *file, int use,
 }
 
 
-#ifdef BSD42
+#ifdef HAVE_LSTAT
 static int
 copyf (char *ifile, char *ofile)
 {
@@ -421,7 +422,7 @@ copyf (char *ifile, char *ofile)
 
     return i;
 }
-#endif /* BSD42 */
+#endif /* HAVE_LSTAT */
 
 
 /* SEND */
@@ -433,7 +434,7 @@ sendfile (char **arg, char *file, int pushsw)
     register int i, vecp;
     char *cp, *sp, *vec[MAXARGS];
 
-#ifdef	MIME
+#ifdef MIME
     if ((cp = m_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
 	    && mhnfile (file)
@@ -530,107 +531,90 @@ mhnfile (char *msgnam)
 
 
 static struct swit  sendswitches[] = {
-#define	ALIASW	0
-    "alias aliasfile", 0,
+#define	ALIASW            0
+    { "alias aliasfile", 0 },
+#define	DEBUGSW           1
+    { "debug", -5 },
 
-#define	DEBUGSW	1
-    "debug", -5,
-
-#define	ENCRSW	2
-    "encrypt",
+#define	ENCRSW            2
 #ifndef	TMA
-    -7,
-#else	/* TMA */
-    0,
-#endif	/* TMA */
-#define	NENCRSW	3
-    "noencrypt",
+    { "encrypt", -7 },
+#else
+    { "encrypt", 0 },
+#endif
+
+#define	NENCRSW           3
 #ifndef	TMA
-    -9,
-#else	/* TMA */
-    0,
-#endif	/* TMA */
+    { "noencrypt", -9 },
+#else
+    { "noencrypt", 0 },
+#endif
 
-#define	FILTSW	4
-    "filter filterfile", 0,
-#define	NFILTSW	5
-    "nofilter", 0,
-
-#define	FRMTSW	6
-    "format", 0,
-#define	NFRMTSW	7
-    "noformat", 0,
-
-#define	FORWSW	8
-    "forward", 0,
-#define	NFORWSW	9
-    "noforward", 0,
-
-#define	MIMESW	10
-    "mime", MIMEminc(-4),
-#define	NMIMESW	11
-    "nomime", MIMEminc(-6),
-
-#define	MSGDSW	12
-    "msgid", 0,
-#define	NMSGDSW	13
-    "nomsgid", 0,
-
-#define	SPSHSW	14
-    "push", 0,
-#define	NSPSHSW	15
-    "nopush", 0,
-
-#define	SPLITSW	16
-    "split seconds", MIMEminc(-5),
-
-#define	UNIQSW	17
-    "unique", -6,
-#define	NUNIQSW	18
-    "nounique", -8,
-
-#define	VERBSW	19
-    "verbose", 0,
-#define	NVERBSW	20
-    "noverbose", 0,
-
-#define	WATCSW	21
-    "watch", 0,
-#define	NWATCSW	22
-    "nowatch", 0,
-
-#define	WIDTHSW	23
-    "width columns", 0,
-
-#define SVERSIONSW 24
-    "version", 0,
-#define	SHELPSW	25
-    "help", 4,
-
-#define	MAILSW	26
-    "mail", -4,
-#define	SAMLSW	27
-    "saml", -4,
-#define	SSNDSW	28
-    "send", -4,
-#define	SOMLSW	29
-    "soml", -4,
-
-#define	CLIESW	30
-    "client host", -6,
-#define	SERVSW	31
-    "server host", -6,
-#define	SNOOPSW	32
-    "snoop", -5,
-
-#define SDRFSW 33
-    "draftfolder +folder", -6,
-#define SDRMSW 34
-    "draftmessage msg", -6,
-#define SNDRFSW 35
-    "nodraftfolder", -3,
-
-    NULL, 0
+#define	FILTSW            4
+    { "filter filterfile", 0 },
+#define	NFILTSW           5
+    { "nofilter", 0 },
+#define	FRMTSW            6
+    { "format", 0 },
+#define	NFRMTSW           7
+    { "noformat", 0 },
+#define	FORWSW            8
+    { "forward", 0 },
+#define	NFORWSW           9
+    { "noforward", 0 },
+#define	MIMESW           10
+    { "mime", MIMEminc(-4) },
+#define	NMIMESW          11
+    { "nomime", MIMEminc(-6) },
+#define	MSGDSW           12
+    { "msgid", 0 },
+#define	NMSGDSW          13
+    { "nomsgid", 0 },
+#define	SPSHSW           14
+    { "push", 0 },
+#define	NSPSHSW          15
+    { "nopush", 0 },
+#define	SPLITSW          16
+    { "split seconds", MIMEminc(-5) },
+#define	UNIQSW           17
+    { "unique", -6 },
+#define	NUNIQSW          18
+    { "nounique", -8 },
+#define	VERBSW           19
+    { "verbose", 0 },
+#define	NVERBSW          20
+    { "noverbose", 0 },
+#define	WATCSW           21
+    { "watch", 0 },
+#define	NWATCSW          22
+    { "nowatch", 0 },
+#define	WIDTHSW          23
+    { "width columns", 0 },
+#define SVERSIONSW       24
+    { "version", 0 },
+#define	SHELPSW          25
+    { "help", 4 },
+#define	MAILSW           26
+    { "mail", -4 },
+#define	SAMLSW           27
+    { "saml", -4 },
+#define	SSNDSW           28
+    { "send", -4 },
+#define	SOMLSW           29
+    { "soml", -4 },
+#define	CLIESW           30
+    { "client host", -6 },
+#define	SERVSW           31
+    { "server host", -6 },
+#define	SNOOPSW          32
+    { "snoop", -5 },
+#define SDRFSW           33
+    { "draftfolder +folder", -6 },
+#define SDRMSW           34
+    { "draftmessage msg", -6 },
+#define SNDRFSW          35
+    { "nodraftfolder", -3 },
+    { NULL, 0 }
 };
 
 
@@ -679,7 +663,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
     vec[vecp++] = "-library";
     vec[vecp++] = getcpy (m_maildir (""));
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, sendswitches)) {
 		case AMBIGSW: 
@@ -779,7 +763,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	advise (NULL, "usage: %s [switches]", sp);
 	return;
     }
-    if (cp = m_find ("Aliasfile")) {	/* allow Aliasfile: profile entry */
+    if ((cp = m_find ("Aliasfile"))) {	/* allow Aliasfile: profile entry */
 	char *dp = NULL;
 
 	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++) {
@@ -788,30 +772,30 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	}
     }
 
-#ifdef	TMA
+#ifdef TMA
     if ((cp = getenv ("KDS")) == NULL || *cp == NULL)
 	if ((cp = m_find ("kdsproc")) && *cp)
 	    m_putenv ("KDS", cp);
     if ((cp = getenv ("TMADB")) == NULL || *cp == NULL)
 	if ((cp = m_find ("tmadb")) && *cp)
 	    m_putenv ("TMADB", m_maildir (cp));
-#endif	/* TMA */
+#endif /* TMA */
 
     if ((cp = getenv ("SIGNATURE")) == NULL || *cp == 0)
 	if ((cp = m_find ("signature")) && *cp)
 	    m_putenv ("SIGNATURE", cp);
-#ifdef	UCI
+#ifdef UCI
 	else {
 	    sprintf (buf, "%s/.signature", mypath);
 	    if ((fp = fopen (buf, "r")) != NULL
 		&& fgets (buf, sizeof buf, fp) != NULL) {
 		    fclose (fp);
-		    if (cp = index (buf, '\n'))
+		    if (cp = strchr (buf, '\n'))
 			*cp = 0;
 		    m_putenv ("SIGNATURE", buf);
 	    }
 	}
-#endif	/* UCI */
+#endif /* UCI */
 
     if ((annotext = getenv ("mhannotate")) == NULL || *annotext == 0)
 	annotext = NULL;
@@ -822,9 +806,9 @@ sendit (char *sp, char **arg, char *file, int pushed)
 
     if ((cp = getenv ("mhdist"))
 	    && *cp
-#ifndef	lint
+#ifndef lint
 	    && (distsw = atoi (cp))
-#endif	/* not lint */
+#endif /* not lint */
 	    && altmsg) {
 	vec[vecp++] = "-dist";
 	distfile = getcpy (m_scratch (altmsg, invo_name));
@@ -836,7 +820,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 
     if (altmsg == NULL || stat (altmsg, &st) == NOTOK)
 	st.st_mtime = 0, st.st_dev = 0, st.st_ino = 0;
-    if (pushsw = pushed)
+    if ((pushsw = pushed))
 	push ();
 
     vec[0] = r1bindex (postproc, '/');
