@@ -6,12 +6,6 @@
  */
 
 #include <h/mh.h>
-
-#if defined(SYS5) && defined(AUX)
-# define u_short ushort
-# define u_long  ulong
-#endif
-
 #include <mts.h>
 #include <errno.h>
 #include <sys/socket.h>
@@ -116,7 +110,7 @@ client (char *args, char *protocol, char *service, int rproto, char *response)
     
 
     if ((sp = getservbyname (service, protocol)) == NULL) {
-#ifdef	HESIOD
+#ifdef HESIOD
 	if ((sp = hes_getservbyname (service, protocol)) == NULL) {
 	    sprintf (response, "%s/%s: unknown service", protocol, service);
 	    return NOTOK;
@@ -258,7 +252,7 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
 	    return OOPS2;
 	}
     }
-#endif	/* KPOP */
+#endif /* KPOP */
 
     return sd;
 }
@@ -297,7 +291,7 @@ getport (int rproto, int addrtype, char *response)
     memset((char *) isock, 0, sizeof *isock);
     isock->sin_family = addrtype;
     for (port = IPPORT_RESERVED - 1;;) {
-	isock->sin_port = htons ((u_short) port);
+	isock->sin_port = htons ((ushort) port);
 	if (bind (sd, (struct sockaddr *) isock, sizeof *isock) != NOTOK)
 	    return sd;
 
@@ -345,18 +339,18 @@ struct hostent *
 gethostbystring (char *s)
 {
     register struct hostent *h;
-#ifndef	DG
-    static u_long iaddr;
-#else
-    static struct in_addr iaddr;
-#endif
     static struct hostent hs;
+#ifdef DG
+    static struct in_addr iaddr;
+#else
+    static ulong iaddr;
+#endif
 
     iaddr = inet_addr (s);
-#ifndef	DG
-    if (iaddr == NOTOK && strcmp (s, "255.255.255.255"))
-#else
+#ifdef DG
     if (iaddr.s_addr == NOTOK && strcmp (s, "255.255.255.255"))
+#else
+    if (iaddr == NOTOK && strcmp (s, "255.255.255.255"))
 #endif
 	return gethostbyname (s);
 
@@ -365,7 +359,7 @@ gethostbystring (char *s)
     h->h_aliases = &empty;
     h->h_addrtype = AF_INET;
     h->h_length = sizeof (iaddr);
-#ifdef	h_addr
+#ifdef h_addr
     h->h_addr_list = addrs;
     memset((char *) addrs, 0, sizeof addrs);
 #endif
