@@ -7,6 +7,10 @@
 
 #include <h/mh.h>
 
+#ifdef HAVE_ERRNO_H
+# include <errno.h>
+#endif
+
 #ifdef MMDFONLY
 # define LOCKONLY
 #endif
@@ -22,24 +26,18 @@
 # endif	/* not MMDFONLY */
 #endif	/* LOCKONLY */
 
-#ifdef LOCKF
-# include <sys/errno.h>
-# include <sys/file.h>
-#endif
-
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
 #else
 # include <sys/file.h>
 #endif
 
-#include <signal.h>
-
-#ifdef SYS5
-# define u_short ushort
-# define u_long ulong
+#if defined(LOCKF) || defined(FLOCK)
+# include <sys/file.h>
 #endif
 
+#include <signal.h>
+
 extern int errno;
 
 #if defined(LOCKONLY) && !defined(MMDFONLY)
@@ -67,10 +65,10 @@ lockfile (int fd)
 #ifdef FCNTL
     struct flock fl;
  
-    fl.l_type = F_WRLCK;
-    fl.l_whence = 0;
-    fl.l_start = 0;
-    fl.l_len = 0;
+    fl.l_type   = F_WRLCK;
+    fl.l_whence = SEEK_SET;
+    fl.l_start  = 0;
+    fl.l_len    = 0;
     if (fcntl (fd, F_SETLK, &fl) == -1) 
         return -1;
 #endif
@@ -224,10 +222,13 @@ f_lkopen (char *file, int access)
 
 # if defined(LOCKF) || defined(FCNTL)
 	j = access;
-	access &= ~O_APPEND;	/* make sure we open at the beginning */
+	/* make sure we open at the beginning */
+	access &= ~O_APPEND;
 	if ((access & 03) == O_RDONLY) {
-	/* We MUST have write permission or lockf/fcntl() won't work */
-	/* (Stupid eh?) */
+	    /*
+	     * We MUST have write permission or
+	     * lockf/fcntl() won't work
+	     */
 	    access &= ~O_RDONLY;
 	    access |= O_RDWR;
 	}
@@ -236,38 +237,31 @@ f_lkopen (char *file, int access)
 	if ((fd = open (file, access | O_NDELAY)) == NOTOK)
 	    return NOTOK;
 
-# ifndef LOCKF
-#  ifndef FLOCK
-#   ifndef FCNTL
-
-	/* should be an error? */
-#   else /* FCNTL */
-
-	buf.l_type = F_WRLCK;
-	buf.l_whence = 0;
-	buf.l_start = 0;
-	buf.l_len = 0;
+# ifdef FCNTL
+	buf.l_type   = F_WRLCK;
+	buf.l_whence = SEEK_SET;
+	buf.l_start  = 0;
+	buf.l_len    = 0;
 	if (fcntl (fd, F_SETLK, &buf) != NOTOK)
 	    return fd;
-#   endif
-#  else /* FLOCK */
+# endif
+
+# ifdef FLOCK
 	if (flock (fd, LOCK_EX | LOCK_NB) != NOTOK)
 	    return fd;
-#  endif
-# else /* LOCKF */
+# endif
+
+# ifdef LOCKF
 	if (lockf (fd, F_TLOCK, 0L) != NOTOK) {
 	    /* see if we should be at the end */
 	    if (j & O_APPEND)
 		lseek (fd, (off_t) 0, SEEK_END);
 	    return fd;
 	}
-	/* Fix errno - lockf screws it */
-	if (errno == EACCES)
-	    errno = EWOULDBLOCK;
 # endif
+
 	j = errno;
 	close (fd);
-
 	sleep (5);
     }
 
@@ -294,24 +288,23 @@ lkclose (int fd, char *file)
     switch (lockstyle) {
 	case LOK_UNIX: 
 
-#ifndef LOCKF
-# ifndef FLOCK
-#  ifndef FCNTL
-	/* should be an error? */
-#  else	/* FCNTL */
-	    buf.l_type = F_UNLCK;
-	    buf.l_whence = 0;
-	    buf.l_start = 0;
-	    buf.l_len = 0;
+#ifdef FCNTL
+	    buf.l_type   = F_UNLCK;
+	    buf.l_whence = SEEK_SET;
+	    buf.l_start  = 0;
+	    buf.l_len    = 0;
 	    fcntl(fd, F_SETLK, &buf);
 	    break;
-#  endif
-# else	/* FLOCK */
+#endif
+
+#ifdef FLOCK
 	    flock (fd, LOCK_UN);
 	    break;
-# endif
-#else /* LOCKF */
-	    lseek (fd, (off_t) 0, SEEK_SET); /* make sure we unlock the whole thing */
+#endif
+
+#ifdef LOCKF
+	    /* make sure we unlock the whole thing */
+	    lseek (fd, (off_t) 0, SEEK_SET);
 	    lockf (fd, F_ULOCK, 0L);
 	    break;
 #endif	
@@ -362,23 +355,22 @@ lkfclose (FILE *fp, char *file)
 
     switch (lockstyle) {
 	case LOK_UNIX: 
-#ifndef LOCKF
-# ifndef FLOCK
-#  ifndef FCNTL
-	/* should be an error? */
-#  else	/* FCNTL */
-	    buf.l_type = F_UNLCK;
-	    buf.l_whence = 0;
-	    buf.l_start = 0;
-	    buf.l_len = 0;
+
+#ifdef FCNTL
+	    buf.l_type   = F_UNLCK;
+	    buf.l_whence = SEEK_SET;
+	    buf.l_start  = 0;
+	    buf.l_len    = 0;
 	    fcntl(fileno(fp), F_SETLK, &buf);
 	    break;
-#  endif
-# else /* FLOCK */
+#endif
+
+#ifdef FLOCK
 	    flock (fileno(fp), LOCK_UN);
 	    break;
-# endif
-#else	/* LOCKF */
+#endif
+
+#ifdef LOCKF
 	    fseek (fp, 0L, 0); /* make sure we unlock the whole thing */
 	    lockf (fileno(fp), F_ULOCK, 0L);
 	    break;
@@ -395,20 +387,17 @@ lkfclose (FILE *fp, char *file)
 }
 
 
-#define	NSECS ((unsigned) 20)
-
-
 struct lock {
     int	l_fd;
     char *l_lock;
     struct lock *l_next;
 };
+
 #define	NULLP ((struct lock *) 0)
+#define	NSECS ((unsigned) 20)
 
 static struct lock *l_top = NULLP;
 
-
-
 static RETSIGTYPE
 alrmser (int sig)
 {
