@@ -8,9 +8,9 @@
 #include <h/nmh.h>
 #include <tws.h>
 
-#if !defined(SYS5) && !defined(ZONEINFO)
+#if !defined(HAVE_TZSET) && !defined(HAVE_TM_GMTOFF)
 # include <sys/timeb.h>
-#endif	/* !defined(SYS5) && !defined(ZONEINFO) */
+#endif
 
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -23,7 +23,7 @@
 # endif
 #endif
 
-#ifdef SYS5
+#ifdef HAVE_TZSET
 extern int daylight;
 extern long timezone;
 extern char *tzname[];
@@ -126,7 +126,7 @@ static struct zone zones[] = {
 char *
 dtimenow(void)
 {
-    long clock;
+    time_t clock;
 
     time (&clock);
     return dtime (&clock);
@@ -153,7 +153,7 @@ dctime (struct tws *tw)
 struct tws *
 dtwstime (void)
 {
-    long clock;
+    time_t clock;
 
     time (&clock);
     return dlocaltime (&clock);
@@ -161,11 +161,11 @@ dtwstime (void)
 
 
 struct tws *
-dlocaltime (long *clock)
+dlocaltime (time_t *clock)
 {
     register struct tm *tm;
 
-#if !defined(SYS5) && !defined(ZONEINFO)
+#if !defined(HAVE_TZSET) && !defined(HAVE_TM_GMTOFF)
     struct timeb tb;
 #endif
 
@@ -187,11 +187,11 @@ dlocaltime (long *clock)
     if (tm->tm_isdst)
 	tw.tw_flags |= TW_DST;
 
-#ifdef SYS5
+#ifdef HAVE_TZSET
     tzset();
     tw.tw_zone = -(timezone / 60);
 #else
-# ifdef ZONEINFO
+# ifdef HAVE_TM_GMTOFF
     tw.tw_zone = tm->tm_gmtoff / 60;
     if (tm->tm_isdst)			/* if DST is in effect */
 	tw.tw_zone -= 60;		/* reset to normal offset */
@@ -210,7 +210,7 @@ dlocaltime (long *clock)
 
 
 struct tws *
-dgmtime (long *clock)
+dgmtime (time_t *clock)
 {
     register struct tm *tm;
     static struct tws   tw;
@@ -287,7 +287,7 @@ dtimezone (int offset, int flags)
     }
 
     if (!(flags & TW_ZONE) && mins == 0) {
-#if defined(SYS5) && defined(TZNAME)
+#if defined(HAVE_TZSET) && defined(HAVE_TZNAME)
 	tzset();
 	return ((flags & TW_DST) ? tzname[1] : tzname[0]);
 #else
@@ -330,11 +330,11 @@ twscopy (struct tws *tb, struct tws *tw)
 int
 twsort (struct tws *tw1, struct tws *tw2)
 {
-    register long c1, c2;
+    time_t c1, c2;
 
-    if (tw1->tw_clock == 0L)
+    if (tw1->tw_clock == 0)
 	twclock (tw1);
-    if (tw2->tw_clock == 0L)
+    if (tw2->tw_clock == 0)
 	twclock (tw2);
 
     return ((c1 = tw1->tw_clock) > (c2 = tw2->tw_clock) ? 1
@@ -353,13 +353,13 @@ static int dmsize[] = {
 };
 
 
-long
+time_t
 twclock (struct tws *tw)
 {
     int i, sec, min, hour, mday, mon, year;
-    register long result;
+    time_t result;
 
-    if (tw->tw_clock != 0L)
+    if (tw->tw_clock != 0)
 	return tw->tw_clock;
 
     if ((sec = tw->tw_sec) < 0 || sec > 59
@@ -370,7 +370,7 @@ twclock (struct tws *tw)
 	return (tw->tw_clock = -1L);
     year = tw->tw_year;
 
-    result = 0L;
+    result = 0;
     if (year < 100)
 	year += CENTURY;
     for (i = 1970; i < year; i++)
